@@ -3,7 +3,6 @@ import logging
 import os
 import platform
 import socket
-import warnings
 from dataclasses import dataclass
 from subprocess import Popen, PIPE, TimeoutExpired
 from typing import Any
@@ -22,11 +21,12 @@ ch.setLevel(logging.INFO)
 ch.setFormatter(formatter)
 logger.addHandler(ch)
 
+
 # File logger
-fh = logging.FileHandler(f'{logger_name}.log', mode='w', encoding='utf8')
-fh.setLevel(logging.DEBUG)
-fh.setFormatter(formatter)  # Add the formatter
-logger.addHandler(fh)  # Add the handlers to the logger
+# fh = logging.FileHandler(f'{logger_name}.log', mode='w', encoding='utf8')
+# fh.setLevel(logging.DEBUG)
+# fh.setFormatter(formatter)  # Add the formatter
+# logger.addHandler(fh)  # Add the handlers to the logger
 
 
 @dataclass()
@@ -175,6 +175,11 @@ class Plinux:
 
             # Get STDERR
             stderr = stderr.read().decode().strip()
+
+            # Clear stderr if password prompt detected
+            if '[sudo] password for' in stderr:
+                stderr = None
+
             err = stderr if stderr else None
             if err:
                 logger.error(err)
@@ -192,39 +197,6 @@ class Plinux:
     def __sudo_cmd(self):
         return f'sudo -S <<< {self.password}'
 
-    def send_cmd(self, cmd: str, sudo: bool = False):
-        """Base method to execute SSH command on remote server
-
-        :param cmd: SSH command
-        :param sudo: Execute specified command as sudo user
-        :return: Decoded command result
-        """
-
-        warnings.warn('"send_cmd" is deprecated and will be removed. Use "run_cmd" method instead', DeprecationWarning)
-
-        client = self._client()
-
-        try:
-            cmd_ = f'sudo -S <<< "{self.password}" {cmd}' if sudo else cmd
-
-            logger.info(f'[{self.host}] [{self.username}@{self.password}] "{cmd_}"')
-
-            stdin, stdout, stderr = client.exec_command(cmd_)
-            data = (stdout.read() + stderr.read()).decode().strip()
-
-            logger.info(f'[RESULT] "{data}"')
-
-            # pretty print - remove sudo prompt
-            sudo_prompt = '[sudo] password for user:'
-            if sudo_prompt in data:
-                if sudo_prompt == data:
-                    return None
-                return data.split('[sudo] password for user: ')[1]
-
-            return data
-        finally:
-            client.close()
-
     def is_credentials_valid(self):
         try:
             self.run_cmd('whoami')
@@ -447,15 +419,28 @@ class Plinux:
         return self.run_cmd(cmd)
 
     def copy_file(self, src: str, dst: str):
-        """
+        """Copy file to another location
 
-        :param src:
-        :param dst:
+        :param src: Source full path
+        :param dst: Destination
         :return:
         """
 
         return self.run_cmd(f'cp {src} {dst}', sudo=True)
 
+    def get_md5(self, path: str, raw: bool = False):
+        """
+        Get file md5
+
+        :param path: File path
+        :param raw: Return md5 sum only (not Rseponse object)
+        """
+
+        result = self.run_cmd(f'md5sum {path}').stdout
+        if raw:
+            return result.split(path)[0].strip()
+        return result
+
     def get_processes(self):
         return self.run_cmd(f'ps -aux')
 
@@ -572,3 +557,4 @@ class Plinux:
     chpasswd = change_password
     count = count_files
     stat = get_file_permissions
+    md5 = get_md5
